CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
53 lines
2.1 KiB
Plaintext
53 lines
2.1 KiB
Plaintext
// RUN: %run_test hipify "%s" "%t" %hipify_args 2 --skip-excluded-preprocessor-conditional-blocks --experimental %clang_args
|
|
|
|
// CHECK: #include <hip/hip_runtime.h>
|
|
#include <cuda_runtime.h>
|
|
#include <string>
|
|
#include <stdio.h>
|
|
|
|
int main() {
|
|
printf("12.12000. CUDA Runtime API Functions synthetic test for CUDA >= 12000\n");
|
|
|
|
// CHECK: hipError_t result = hipSuccess;
|
|
cudaError result = cudaSuccess;
|
|
|
|
// CHECK: hipGraphExec_t GraphExec_t;
|
|
cudaGraphExec_t GraphExec_t;
|
|
|
|
// CHECK: hipGraph_t Graph_t;
|
|
cudaGraph_t Graph_t;
|
|
|
|
void *pfn = nullptr;
|
|
std::string symbol = "symbol";
|
|
|
|
#if defined(_WIN32) && CUDA_VERSION < 9000
|
|
typedef signed __int64 int64_t;
|
|
typedef unsigned __int64 uint64_t;
|
|
#endif
|
|
|
|
#if defined(_WIN32)
|
|
unsigned long long ull = 0;
|
|
#else
|
|
unsigned long ull = 0;
|
|
#endif
|
|
|
|
#if CUDA_VERSION >= 12000
|
|
// CUDA: extern __host__ cudaError_t CUDARTAPI cudaGraphInstantiate(cudaGraphExec_t *pGraphExec, cudaGraph_t graph, unsigned long long flags __dv(0));
|
|
// HIP: hipError_t hipGraphInstantiateWithFlags(hipGraphExec_t* pGraphExec, hipGraph_t graph, unsigned long long flags);
|
|
// CHECK: result = hipGraphInstantiateWithFlags(&GraphExec_t, Graph_t, ull);
|
|
result = cudaGraphInstantiate(&GraphExec_t, Graph_t, ull);
|
|
|
|
// CHECK: hipDriverEntryPointQueryResult driverProcAddressQueryResult;
|
|
cudaDriverEntryPointQueryResult driverProcAddressQueryResult;
|
|
|
|
// CUDA: extern __host__ cudaError_t CUDARTAPI cudaGetDriverEntryPoint(const char *symbol, void **funcPtr, unsigned long long flags, enum cudaDriverEntryPointQueryResult *driverStatus = NULL);
|
|
// CUDA < 12000: extern __host__ cudaError_t CUDARTAPI cudaGetDriverEntryPoint(const char *symbol, void **funcPtr, unsigned long long flags);
|
|
// NOTE: cudaGetDriverEntryPoint for CUDA < 12000 is not supported by HIP
|
|
// HIP: hipError_t hipGetDriverEntryPoint(const char* symbol, void** funcPtr, unsigned long long flags, hipDriverEntryPointQueryResult* driverStatus);
|
|
// CHECK: result = hipGetDriverEntryPoint(symbol.c_str(), &pfn, 800, ull, &driverProcAddressQueryResult);
|
|
result = cudaGetDriverEntryPoint(symbol.c_str(), &pfn, ull, &driverProcAddressQueryResult);
|
|
#endif
|
|
|
|
return 0;
|
|
}
|